flybot.oie.session


logout-handlerclj

(logout-handler {:keys [redirect-uri] :or {redirect-uri "/"}})

Returns a Ring handler that clears the session on POST and redirects. Returns 405 for non-POST requests. Callers should apply ring.middleware.anti-forgery/wrap-anti-forgery to protect against cross-site request forgery. redirect-uri defaults to "/".

Returns a Ring handler that clears the session on POST and redirects.
Returns 405 for non-POST requests.
Callers should apply `ring.middleware.anti-forgery/wrap-anti-forgery`
to protect against cross-site request forgery.
`redirect-uri` defaults to "/".
sourceraw docstring

session-keyclj

Key under which the authenticated identity is stored in the Ring session. Used internally by session-strategy, wrap-oauth2, and wrap-magic-link.

Key under which the authenticated identity is stored in the Ring session.
Used internally by session-strategy, wrap-oauth2, and wrap-magic-link.
sourceraw docstring

session-timeout-handlerclj

(session-timeout-handler {:keys [redirect-uri] :or {redirect-uri "/"}})

Returns a Ring handler for session timeout responses. Returns 401 with a redirect hint for clients to handle re-authentication. Intended for use with ring.middleware.session-timeout/wrap-idle-session-timeout.

Returns a Ring handler for session timeout responses.
Returns 401 with a redirect hint for clients to handle re-authentication.
Intended for use with `ring.middleware.session-timeout/wrap-idle-session-timeout`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries