Clojure only.

flybot.oie.strategy.session


session-strategyclj

(session-strategy)

Returns a strategy map that checks the session for an authenticated user. Reads identity from the hardcoded session key ::session/user.

Returns a strategy map that checks the session for an authenticated user.
Reads identity from the hardcoded session key `::session/user`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries