(session-strategy)Returns a strategy map that checks the session for an authenticated user.
Reads identity from the hardcoded session key ::session/user.
Returns a strategy map that checks the session for an authenticated user. Reads identity from the hardcoded session key `::session/user`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |